@@ -163,9 +163,10 @@ class ManageVM(object):
                     "Failed to copy Salt configuration to {}".
                     format(dispvm.name))
             p = dispvm.run_service('qubes.SaltLinuxVM', user='root')
-            (untrusted_stdout, _) = p.communicate(
+            (untrusted_stdout, untrusted_stderr) = p.communicate(
                     (self.vm.name + '\n' + command + '\n').encode())
-            untrusted_stdout = untrusted_stdout.decode('ascii', errors='ignore')
+            untrusted_stdout = untrusted_stdout.decode('ascii', errors='ignore') + \
+                               untrusted_stderr.decode('ascii', errors='ignore')
             if not self.force_color:
                 # removing control characters, unless colors are enabled
                 stdout_lines = [
